from abc import ABC, abstractmethod

from bot_data.model.server_afk_channel_ids_config import ServerAFKChannelIdsConfig
from bot_data.model.server_config import ServerConfig
from bot_data.model.server_team_role_ids_config import ServerTeamRoleIdsConfig


class ServerConfigRepositoryABC(ABC):
    @abstractmethod
    def __init__(self):
        pass

    @abstractmethod
    def does_server_config_exists(self, server_id: int) -> bool:
        pass

    @abstractmethod
    def get_server_config_by_server(self, server_id: int) -> ServerConfig:
        pass

    @abstractmethod
    def get_server_config_by_id(self, config_id: int) -> ServerConfig:
        pass

    @abstractmethod
    def add_server_config(self, server_config: ServerConfig):
        pass

    @abstractmethod
    def update_server_config(self, server_config: ServerConfig):
        pass

    @abstractmethod
    def delete_server_config(self, server_config: ServerConfig):
        pass

    @abstractmethod
    def add_server_team_role_id_config(self, server_team_role_id: ServerTeamRoleIdsConfig):
        pass

    @abstractmethod
    def update_server_team_role_id_config(self, server_team_role_id: ServerTeamRoleIdsConfig):
        pass

    @abstractmethod
    def delete_server_team_role_id_config(self, server_team_role_id: ServerTeamRoleIdsConfig):
        pass

    @abstractmethod
    def add_server_afk_channel_config(self, server_afk_channel: ServerAFKChannelIdsConfig):
        pass

    @abstractmethod
    def update_server_afk_channel_config(self, server_afk_channel: ServerAFKChannelIdsConfig):
        pass

    @abstractmethod
    def delete_server_afk_channel_config(self, server_afk_channel: ServerAFKChannelIdsConfig):
        pass
